@@ -139,8 +139,8 @@ document_tile_new (const gchar *in_uri, const gchar *mime_type, time_t modified)
 	gchar *markup;
 
 	AtkObject *accessible;
-	
-	gchar *filename;
+
+	GFile * file;
 	gchar *tooltip_text;
 
 	libslab_checkpoint ("document_tile_new(): start");
@@ -158,14 +158,9 @@ document_tile_new (const gchar *in_uri, const gchar *mime_type, time_t modified)
 	time_str = create_subheader_string (modified);
 	subheader = create_subheader (time_str);
 	
-	filename = g_filename_from_uri (uri, NULL, NULL);
-
-  	if (filename)
-		tooltip_text = g_filename_to_utf8 (filename, -1, NULL, NULL, NULL);
-	else
-		tooltip_text = NULL;
-
-	g_free (filename);
+	file = g_file_new_for_uri (uri);
+	tooltip_text = g_file_get_parse_name (file);
+	g_object_unref (file);
 	
 	context_menu = GTK_MENU (gtk_menu_new ());
 
@@ -323,11 +318,14 @@ document_tile_private_setup (DocumentTile *this)
 	GAppInfo *app;
 
 	GConfClient *client;
+	GError *error = NULL;
 
 	file = g_file_new_for_uri (TILE (this)->uri);
-	app = g_file_query_default_handler (file, NULL, NULL);
+	app = g_file_query_default_handler (file, NULL, &error);
 	priv->default_app = app;
 
+	if (error)
+		g_error_free (error);
 	g_object_unref (file);
 
 	priv->delete_enabled =
@@ -383,7 +381,8 @@ document_tile_finalize (GObject *g_object)
 	g_free (priv->mime_type);
 	g_free (priv->force_icon_name);
 
-	g_object_unref (priv->default_app);
+	if (priv->default_app)
+		g_object_unref (priv->default_app);
 
 	if (priv->notify_signal_id)
 		g_signal_handler_disconnect (priv->agent, priv->notify_signal_id);
@@ -417,7 +416,7 @@ load_image (DocumentTile *tile)
 
 	libslab_checkpoint ("document-tile.c: load_image(): start for %s", TILE (tile)->uri);
 
-	if (priv->force_icon_name || ! priv->mime_type || ! strstr (TILE (tile)->uri, "file://")) {
+	if (priv->force_icon_name || ! priv->mime_type) {
 		if (priv->force_icon_name)
 			icon_id = priv->force_icon_name;
 		else
@@ -881,30 +880,29 @@ open_with_default_trigger (Tile *tile, TileEvent *event, TileAction *action)
 static void
 open_in_file_manager_trigger (Tile *tile, TileEvent *event, TileAction *action)
 {
-	gchar *filename;
-	gchar *dirname;
+	GFile *filename;
+	GFile *dirname;
 	gchar *uri;
 
 	gchar *cmd;
 
-	filename = g_filename_from_uri (TILE (tile)->uri, NULL, NULL);
-	dirname = g_path_get_dirname (filename);
-	uri = g_filename_to_uri (dirname, NULL, NULL);
-
+	filename = g_file_new_for_uri (TILE (tile)->uri);
+	dirname = g_file_get_parent (filename);
+	uri = g_file_get_uri (dirname);
+	
 	if (!uri)
 		g_warning ("error getting dirname for [%s]\n", TILE (tile)->uri);
 	else
 	{
 		cmd = string_replace_once (get_slab_gconf_string (SLAB_FILE_MANAGER_OPEN_CMD),
 			"FILE_URI", uri);
-
 		spawn_process (cmd);
 
 		g_free (cmd);
 	}
 
-	g_free (filename);
-	g_free (dirname);
+	g_object_unref (filename);
+	g_object_unref (dirname);
 	g_free (uri);
 }
 
@@ -1023,8 +1021,10 @@ user_docs_trigger (Tile *tile, TileEvent *event, TileAction *action)
 		item->uri       = tile->uri;
 		item->mime_type = priv->mime_type;
 		item->mtime     = priv->modified;
-		item->app_name  = (gchar *) g_app_info_get_name (priv->default_app);
-		item->app_exec  = (gchar *) g_app_info_get_executable (priv->default_app);
+		if (priv->default_app) {
+			item->app_name  = (gchar *) g_app_info_get_name (priv->default_app);
+			item->app_exec  = (gchar *) g_app_info_get_executable (priv->default_app);
+		}
 
 		bookmark_agent_add_item (priv->agent, item);
 		g_free (item);
