@@ -33,13 +33,7 @@
 #include <gdk/gdkkeysyms.h>
 #include <X11/Xlib.h>
 #include <gdk/gdkx.h>
-#include <libgnomevfs/gnome-vfs.h>
-#include <libgnomevfs/gnome-vfs-mime-handlers.h>
-
-#include <gtk/gtkversion.h>
-#if GTK_CHECK_VERSION (2, 10, 0)
-#	define USE_GTK_RECENT_MANAGER
-#endif
+#include <gio/gio.h>
 
 #include "tile.h"
 #include "application-tile.h"
@@ -122,11 +116,11 @@ typedef struct {
 
 	BookmarkAgent *bm_agents [BOOKMARK_STORE_N_TYPES];
 
-	GnomeVFSVolumeMonitor *volume_mon;
+	GVolumeMonitor        *volume_mon;
 	GList                 *mounts;
 
-	guint recently_used_throttle_timeout_id;
-	GnomeVFSMonitorHandle *recently_used_store_monitor;
+	GFileMonitor *recently_used_store_monitor;
+	guint recently_used_timeout_id;
 
 	guint search_cmd_gconf_mntr_id;
 	guint current_page_gconf_mntr_id;
@@ -224,7 +218,7 @@ static void     search_tomboy_bindkey_cb          (gchar *, gpointer);
 static gboolean grabbing_window_event_cb          (GtkWidget *, GdkEvent *, gpointer);
 static void     user_app_agent_notify_cb          (GObject *, GParamSpec *, gpointer);
 static void     user_doc_agent_notify_cb          (GObject *, GParamSpec *, gpointer);
-static void     volume_monitor_mount_cb           (GnomeVFSVolumeMonitor *, GnomeVFSVolume *, gpointer);
+static void     volume_monitor_mount_cb           (GVolumeMonitor *, GMount *, gpointer);
 
 static GdkFilterReturn slab_gdk_message_filter (GdkXEvent *, GdkEvent *, gpointer);
 
@@ -438,10 +432,7 @@ main_menu_ui_finalize (GObject *g_obj)
 	gint i;
 
 	if (priv->recently_used_store_monitor)
-		gnome_vfs_monitor_cancel (priv->recently_used_store_monitor);
-
-	if (priv->recently_used_throttle_timeout_id)
-		g_source_remove (priv->recently_used_throttle_timeout_id);
+		g_file_monitor_cancel (priv->recently_used_store_monitor);
 
 	for (i = 0; i < 4; ++i) {
 		g_object_unref (G_OBJECT (g_object_get_data (
@@ -475,9 +466,9 @@ main_menu_ui_finalize (GObject *g_obj)
 	for (i = 0; i < BOOKMARK_STORE_N_TYPES; ++i)
 		g_object_unref (priv->bm_agents [i]);
 
-	g_list_foreach (priv->mounts, (GFunc) gnome_vfs_volume_unref, NULL);
+	g_list_foreach (priv->mounts, (GFunc) g_object_unref, NULL);
 	g_list_free (priv->mounts);
-	gnome_vfs_volume_monitor_unref (priv->volume_mon);
+	g_object_unref (priv->volume_mon);
 
 	G_OBJECT_CLASS (main_menu_ui_parent_class)->finalize (g_obj);
 }
@@ -818,11 +809,11 @@ create_rct_docs_section (MainMenuUI *this)
 
 	gtk_container_add (ctnr, GTK_WIDGET (priv->file_tables [RCNT_DOCS_TABLE]));
 
-	priv->volume_mon = gnome_vfs_get_volume_monitor ();
-	priv->mounts = gnome_vfs_volume_monitor_get_mounted_volumes (priv->volume_mon);
+	priv->volume_mon = g_volume_monitor_get ();
+	priv->mounts = g_volume_monitor_get_mounts (priv->volume_mon);
 
-	g_signal_connect (priv->volume_mon, "volume_mounted", G_CALLBACK (volume_monitor_mount_cb), this);
-	g_signal_connect (priv->volume_mon, "volume_unmounted", G_CALLBACK (volume_monitor_mount_cb), this);
+	g_signal_connect (priv->volume_mon, "mount-added", G_CALLBACK (volume_monitor_mount_cb), this);
+	g_signal_connect (priv->volume_mon, "mount-removed", G_CALLBACK (volume_monitor_mount_cb), this);
 }
 
 static void
@@ -964,97 +955,75 @@ get_recently_used_store_filename (void)
 {
 	const char *basename;
 
-#ifdef USE_GTK_RECENT_MANAGER
 	basename = ".recently-used.xbel";
-#else
-	basename = ".recently-used";
-#endif
 
 	return g_build_filename (g_get_home_dir (), basename, NULL);
 }
 
-static gboolean
-recently_used_throttle_timeout_cb (gpointer data)
-{
-	MainMenuUI *this = MAIN_MENU_UI (data);
-	MainMenuUIPrivate *priv = PRIVATE (this);
+#define RECENTLY_USED_STORE_THROTTLE_MILLISECONDS 2000
 
-	update_recently_used_sections (this);
-
-	priv->recently_used_throttle_timeout_id = 0;
-
-	return FALSE;
-}
-
-#define RECENTLY_USED_STORE_THROTTLE_SECONDS 2
-
-static void
-setup_recently_used_throttle_timeout (MainMenuUI *this, gboolean is_startup)
-{
-	MainMenuUIPrivate *priv = PRIVATE (this);
-
-	if (priv->recently_used_throttle_timeout_id != 0)
-		g_source_remove (priv->recently_used_throttle_timeout_id);
-
-	/* Some apps do many updates to the recently-used store quickly, like
-	 * when Nautilus or EOG are asked to open a bunch of files at the same
-	 * time.  So, we throttle our updates to the recently-used store to
-	 * avoid re-reading the store more times than needed.
-	 *
-	 * Additionally, we do this in an idle during startup, not a timeout,
-	 * so that the Computer menu will be up to date as soon as possible.
-	 */
-	if (is_startup)
-		priv->recently_used_throttle_timeout_id = g_idle_add (recently_used_throttle_timeout_cb, this);
-	else
-		priv->recently_used_throttle_timeout_id = g_timeout_add_seconds (RECENTLY_USED_STORE_THROTTLE_SECONDS,
-										 recently_used_throttle_timeout_cb,
-										 this);
-}
-
-/* Called from GnomeVFSMonitor when the recently-used store changes.  We'll note
- * this in a flag, and we'll check that flag later, when it is necessary to have
- * an up-to-date view of the recently-used store.
- */
-static void recently_used_store_monitor_changed_cb (GnomeVFSMonitorHandle *handle,
-						    const gchar *monitor_uri,
-						    const gchar *info_uri,
-						    GnomeVFSMonitorEventType event_type,
+static void recently_used_store_monitor_changed_cb (GFileMonitor *monitor,
+						    GFile *f1, GFile *f2,
+						    GFileMonitorEvent event_type,
 						    gpointer data)
 {
 	MainMenuUI *this = MAIN_MENU_UI (data);
 	MainMenuUIPrivate *priv = PRIVATE (this);
 
 	priv->recently_used_store_has_changed = TRUE;
-	setup_recently_used_throttle_timeout (this, FALSE);
+	update_recently_used_sections (this);
 }
 
-/* Creates a GnomeVFSMonitor for the recently-used store, so we can be informed
+static gboolean
+setup_recently_used_throttle_timeout (gpointer data)
+{
+	MainMenuUI *this = data;
+	MainMenuUIPrivate *priv = PRIVATE (this);
+
+	update_recently_used_sections (this);
+	priv->recently_used_timeout_id = 0;
+
+	return FALSE;
+}
+
+/* Creates a GFileMonitor for the recently-used store, so we can be informed
  * when the store changes.
  */
 static void
 setup_recently_used_store_monitor (MainMenuUI *this, gboolean is_startup)
 {
 	MainMenuUIPrivate *priv = PRIVATE (this);
-	char *filename;
-	char *uri;
+	char *path;
+	GFile *file;
+	GFileMonitor *monitor;
 
 	priv->recently_used_store_has_changed = TRUE; /* ensure the store gets read the first time we need it */
 
-	filename = get_recently_used_store_filename ();
-	uri = g_strconcat ("file://", filename, NULL);
-	g_free (filename);
+	path = get_recently_used_store_filename ();
+	file = g_file_new_for_path (path);
+	g_free (path);
 
-	if (gnome_vfs_monitor_add (&priv->recently_used_store_monitor,
-				   uri,
-				   GNOME_VFS_MONITOR_FILE,
-				   recently_used_store_monitor_changed_cb,
-				   this) != GNOME_VFS_OK)
-		priv->recently_used_store_monitor = NULL;
+	monitor = g_file_monitor_file (file, 0, NULL, NULL);
+	if (monitor) {
+		g_file_monitor_set_rate_limit (monitor,
+					       RECENTLY_USED_STORE_THROTTLE_MILLISECONDS);
+		g_signal_connect (monitor, "changed",
+				  G_CALLBACK (recently_used_store_monitor_changed_cb),
+				  this);
+	}
 
-	g_free (uri);
+	g_object_unref (file);
 
-	setup_recently_used_throttle_timeout (this, is_startup);
+	priv->recently_used_store_monitor = monitor;
+
+	if (priv->recently_used_timeout_id != 0)
+		g_source_remove (priv->recently_used_timeout_id);
+
+	if (is_startup)
+		priv->recently_used_timeout_id = g_idle_add (setup_recently_used_throttle_timeout, this);
+	else
+		priv->recently_used_timeout_id = g_timeout_add_seconds (RECENTLY_USED_STORE_THROTTLE_MILLISECONDS / 1000, /* 2 seconds */
+									setup_recently_used_throttle_timeout, this);
 }
 
 static Tile *
@@ -1091,7 +1060,7 @@ static Tile *
 item_to_user_doc_tile (BookmarkItem *item, gpointer data)
 {
 	//force an icon since the thumbnail is basically blank - BNC#373783
-	if (!strcmp (item->title, "BLANK_SPREADSHEET") || !strcmp (item->title, "BLANK_DOCUMENT"))
+	if (item->title && (!strcmp (item->title, "BLANK_SPREADSHEET") || !strcmp (item->title, "BLANK_DOCUMENT")))
 	{
 		if (! strcmp (item->title, "BLANK_SPREADSHEET"))
 			return TILE (document_tile_new_force_icon (item->uri, item->mime_type,
@@ -1108,34 +1077,41 @@ item_to_recent_doc_tile (BookmarkItem *item, gpointer data)
 {
 	MainMenuUIPrivate *priv = PRIVATE (data);
 
-	GnomeVFSVolume *vol;
+	GMount         *mount;
+	GVolume        *volume;
+	GFile          *file;
+	char           *nfs_id;
 	gboolean        is_nfs = FALSE;
-	GnomeVFSURI    *gvfs_uri;
 	gboolean        is_local = TRUE;
 
 	GList *node;
 
-
+	/* we no longer do our own thumbnailing so this "should" not hang on stale mounts, slow endpoints ... */
+	/*
 	if (! g_str_has_prefix (item->uri, "file://"))
 		return NULL;
 
 	for (node = priv->mounts; ! is_nfs && node; node = node->next) {
-		vol = (GnomeVFSVolume *) node->data;
+		mount = node->data;
+		volume = g_mount_get_volume (mount); //need to check for null here
 
-		is_nfs =
-			((gnome_vfs_volume_get_device_type (vol) == GNOME_VFS_DEVICE_TYPE_NFS) &&
-			g_str_has_prefix (item->uri, gnome_vfs_volume_get_activation_uri (vol)));
+		nfs_id = g_volume_get_identifier (volume, G_VOLUME_IDENTIFIER_KIND_NFS_MOUNT);
+		is_nfs = (nfs_id != NULL);
+
+		g_free (nfs_id);
+		g_object_unref (volume);
 	}
 
 	if (is_nfs)
 		return NULL;
 
-	gvfs_uri = gnome_vfs_uri_new (item->uri);
-	is_local = gnome_vfs_uri_is_local (gvfs_uri);
-	gnome_vfs_uri_unref (gvfs_uri);
+	file = g_file_new_for_uri (item->uri);
+	is_local = g_file_is_native (file);
+	g_object_unref (file);
 
 	if (! is_local)
 		return NULL;
+	*/
 
 	if (bookmark_agent_has_item (priv->bm_agents [BOOKMARK_STORE_USER_DOCS], item->uri))
 		return NULL;
@@ -1146,7 +1122,7 @@ item_to_recent_doc_tile (BookmarkItem *item, gpointer data)
 static Tile *
 item_to_dir_tile (BookmarkItem *item, gpointer data)
 {
-	return TILE (directory_tile_new (item->uri, item->title, item->icon));
+	return TILE (directory_tile_new (item->uri, item->title, item->icon, item->mime_type));
 }
 
 static Tile *
@@ -1154,13 +1130,17 @@ item_to_system_tile (BookmarkItem *item, gpointer data)
 {
 	Tile  *tile;
 	gchar *basename;
-
+	gchar *translated_title;
 
 	if (app_is_in_blacklist (item->uri))
 		return NULL;
+	
+	translated_title = item->title ? _(item->title) : NULL;
 
-	tile = TILE (system_tile_new (item->uri, item->title));
+	tile = TILE (system_tile_new (item->uri, translated_title));
 
+	/* with 0.9.12 we start with clean system area - see move_system_area_to_new_set
+	   no longer need this code to clean up old junk
 	if (tile)
 		return tile;
 
@@ -1171,9 +1151,10 @@ item_to_system_tile (BookmarkItem *item, gpointer data)
 		basename = item->uri;
 
 	if (! libslab_strcmp (basename, "control-center.desktop"))
-		tile = TILE (system_tile_new ("gnomecc.desktop", item->title));
+		tile = TILE (system_tile_new ("gnomecc.desktop", translated_title));
 	else if (! libslab_strcmp (basename, "zen-installer.desktop"))
-		tile = TILE (system_tile_new ("package-manager.desktop", item->title));
+		tile = TILE (system_tile_new ("package-manager.desktop", translated_title));
+	*/
 
 	return tile;
 }
@@ -1193,34 +1174,39 @@ static BookmarkItem *
 doc_uri_to_item (const gchar *uri, gpointer data)
 {
 	BookmarkItem *item;
-
-	GnomeVFSFileInfo        *info;
-	GnomeVFSMimeApplication *default_app;
-
+	GFile *file;
+	GFileInfo *info;
+	GAppInfo *default_app;
 
 	item = g_new0 (BookmarkItem, 1);
 
 	item->uri = g_strdup (uri);
 
-	info = gnome_vfs_file_info_new ();
+	file = g_file_new_for_uri (uri);
+	info = g_file_query_info (file,
+				  G_FILE_ATTRIBUTE_TIME_MODIFIED ","
+				  G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE,
+				  0, NULL, NULL);
+	g_object_unref (file);
 
-	gnome_vfs_get_file_info (
-		item->uri, info, 
-		GNOME_VFS_FILE_INFO_GET_MIME_TYPE | GNOME_VFS_FILE_INFO_FORCE_FAST_MIME_TYPE);
-
-	item->mime_type = g_strdup (info->mime_type);
-	item->mtime     = info->mtime;
-
-	if (item->mime_type) {
-		default_app = gnome_vfs_mime_get_default_application (item->mime_type);
-
-		item->app_name = g_strdup (gnome_vfs_mime_application_get_name (default_app));
-		item->app_exec = g_strdup (gnome_vfs_mime_application_get_exec (default_app));
-
-		gnome_vfs_mime_application_free (default_app);
+	if (!info) {
+		item->mtime = 0;
+		item->mime_type = NULL;
+	} else {
+		item->mtime = (time_t) g_file_info_get_attribute_uint64 (info,
+									 G_FILE_ATTRIBUTE_TIME_MODIFIED);
+		item->mime_type = g_strdup (g_file_info_get_content_type (info));
+		g_object_unref (info);
 	}
 
-	gnome_vfs_file_info_unref (info);
+	if (item->mime_type) {
+		default_app = g_app_info_get_default_for_type (item->mime_type, FALSE);
+
+		item->app_name = g_strdup (g_app_info_get_name (default_app));
+		item->app_exec = g_strdup (g_app_info_get_executable (default_app));
+
+		g_object_unref (default_app);
+	}
 
 	if (! (item->mime_type && item->app_name)) {
 		bookmark_item_free (item);
@@ -1842,7 +1828,7 @@ update_recently_used_sections (MainMenuUI *this)
 	}
 
 	if (!priv->recently_used_store_monitor)
-		setup_recently_used_store_monitor (this, FALSE); /* for if we couldn't create the monitor the first time */
+		setup_recently_used_store_monitor (this, FALSE);
 
 	libslab_checkpoint ("main-menu-ui.c: update_recently_used_sections() end");
 }
@@ -1857,6 +1843,7 @@ present_slab_window (MainMenuUI *this)
 
 	update_recently_used_sections (this);
 
+	gtk_window_set_screen (GTK_WINDOW (priv->slab_window), gtk_widget_get_screen (GTK_WIDGET (priv->panel_applet)));
 	gtk_window_present_with_time (GTK_WINDOW (priv->slab_window), gtk_get_current_event_time ());
 }
 
@@ -2526,11 +2513,11 @@ user_doc_agent_notify_cb (GObject *g_obj, GParamSpec *pspec, gpointer user_data)
 }
 
 static void
-volume_monitor_mount_cb (GnomeVFSVolumeMonitor *mon, GnomeVFSVolume *vol, gpointer data)
+volume_monitor_mount_cb (GVolumeMonitor *mon, GMount *mount, gpointer data)
 {
 	MainMenuUIPrivate *priv = PRIVATE (data);
 
-	g_list_foreach (priv->mounts, (GFunc) gnome_vfs_volume_unref, NULL);
+	g_list_foreach (priv->mounts, (GFunc) g_object_unref, NULL);
 	g_list_free (priv->mounts);
-	priv->mounts = gnome_vfs_volume_monitor_get_mounted_volumes (mon);
+	priv->mounts = g_volume_monitor_get_mounts (mon);
 }
