@@ -21,12 +21,12 @@
 #include "network-status-agent.h"
 
 #include <string.h>
-#include <libnm-glib/nm-client.h>
+#include <nm-client.h>
 #include <NetworkManager.h>
-#include <libnm-glib/nm-device-wifi.h>
-#include <libnm-glib/nm-device-ethernet.h>
-#include <libnm-glib/nm-gsm-device.h>
-#include <libnm-glib/nm-cdma-device.h>
+#include <nm-device-wifi.h>
+#include <nm-device-ethernet.h>
+#include <nm-gsm-device.h>
+#include <nm-cdma-device.h>
 #include <nm-setting-ip4-config.h>
 #include <nm-utils.h>
 #include <arpa/inet.h>
@@ -201,8 +201,8 @@ nm_get_device_info (NetworkStatusAgent * agent, NMDevice * device)
 	NetworkStatusInfo *info = g_object_new (NETWORK_STATUS_INFO_TYPE, NULL);
 	const GArray *array;
 	const GSList *addresses;
-	NMSettingIP4Address *def_addr;
-	guint32 hostmask, network, bcast;
+	NMIP4Address *def_addr;
+	guint32 address, netmask, hostmask, network, bcast;
 
 	info->iface = g_strdup (nm_device_get_iface (device));
 	info->driver = g_strdup (nm_device_get_driver (device));
@@ -210,32 +210,35 @@ nm_get_device_info (NetworkStatusAgent * agent, NMDevice * device)
 	if (! info->active)
 		return info;
 	NMIP4Config * cfg = nm_device_get_ip4_config (device);
-	if(! cfg)
-		return info;
-
-	addresses = nm_ip4_config_get_addresses (cfg);
-	if (addresses) {
-		def_addr = addresses->data;
-
-		info->ip4_addr = ip4_address_as_string (def_addr->address);
-		info->subnet_mask = ip4_address_as_string (nm_utils_ip4_prefix_to_netmask (def_addr->prefix));
-		info->route = ip4_address_as_string (def_addr->gateway);
-
-		network = ntohl (def_addr->address) & ntohl (nm_utils_ip4_prefix_to_netmask (def_addr->prefix));
-		hostmask = ~ntohl (nm_utils_ip4_prefix_to_netmask (def_addr->prefix));
-		bcast = htonl (network | hostmask);
-		info->broadcast = ip4_address_as_string (bcast);
-	}
-
-	info->primary_dns = NULL;
-	info->secondary_dns = NULL;
-	array = nm_ip4_config_get_nameservers (cfg);
-	if (array)
+	//According to the documentation this should not be NULL if the device is active but on resume from suspend it is (BNC#463712), so check for now
+	if(cfg)
 	{
-		if (array->len > 0)
-			info->primary_dns = ip4_address_as_string (g_array_index (array, guint32, 0));
-		if (array->len > 1)
-			info->secondary_dns = ip4_address_as_string (g_array_index (array, guint32, 1));
+		addresses = nm_ip4_config_get_addresses (cfg);
+		if (addresses) {
+			def_addr = addresses->data;
+
+			address = nm_ip4_address_get_address (def_addr);
+			netmask = nm_utils_ip4_prefix_to_netmask (nm_ip4_address_get_prefix (def_addr));
+			network = ntohl (address) & ntohl (netmask);
+			hostmask = ~ntohl (netmask);
+			bcast = htonl (network | hostmask);
+
+			info->ip4_addr = ip4_address_as_string (address);
+			info->subnet_mask = ip4_address_as_string (netmask);
+			info->route = ip4_address_as_string (nm_ip4_address_get_gateway (def_addr));
+					info->broadcast = ip4_address_as_string (bcast);
+		}
+
+		info->primary_dns = NULL;
+		info->secondary_dns = NULL;
+		array = nm_ip4_config_get_nameservers (cfg);
+		if (array)
+		{
+			if (array->len > 0)
+				info->primary_dns = ip4_address_as_string (g_array_index (array, guint32, 0));
+			if (array->len > 1)
+				info->secondary_dns = ip4_address_as_string (g_array_index (array, guint32, 1));
+		}
 	}
 
 	if (NM_IS_DEVICE_WIFI(device))
